@@ -198,6 +198,7 @@ class DisplayExtension(QtCore.QObject):
         :param parameters: tool parameters
         :type parameters: :class:`lavuelib.toolWidget.ToolParameters`
         """
+
     def transpose(self):
         """ transposes subwidget
         """
@@ -1760,7 +1761,9 @@ class VHBoundsExtension(DisplayExtension):
             self.__centerHLine2.show()
 
 
-class MarkExtension(DisplayExtension):
+class BaseMarkExtension(DisplayExtension):
+
+    """ base mark extension """
 
     def __init__(self, parent=None):
         """ constructor
@@ -1771,23 +1774,89 @@ class MarkExtension(DisplayExtension):
         DisplayExtension.__init__(self, parent)
 
         #: (:obj:`str`) tool name
-        self.name = "mark"
+        self.name = "basemark"
 
         #: ([:obj:`float`, :obj:`float`]) position mark coordinates
-        self.__markcoordinates = None
+        self._markcoordinates = None
         #: (:obj:`float`) last time in s
-        self.__lasttime = 0.
+        self._lasttime = 0.
 
         #: (:class:`pyqtgraph.InfiniteLine`)
         #:                 vertical mark line of the mouse position
-        self.__markVLine = _pg.InfiniteLine(
-            angle=90, movable=False, pen=(0, 0, 255))
+        self._markVLine = _pg.InfiniteLine(
+            angle=90, movable=False, pen=(255, 255, 255))
         #: (:class:`pyqtgraph.InfiniteLine`)
         #:                   horizontal mark line of the mouse position
-        self.__markHLine = _pg.InfiniteLine(
-            angle=0, movable=False, pen=(0, 0, 255))
-        self._mainwidget.viewbox().addItem(self.__markVLine, ignoreBounds=True)
-        self._mainwidget.viewbox().addItem(self.__markHLine, ignoreBounds=True)
+        self._markHLine = _pg.InfiniteLine(
+            angle=0, movable=False, pen=(255, 255, 255))
+        self._mainwidget.viewbox().addItem(self._markVLine, ignoreBounds=True)
+        self._mainwidget.viewbox().addItem(self._markHLine, ignoreBounds=True)
+
+    def _showMarkLines(self, status):
+        """ shows or hides HV mark mouse lines
+
+        :param status: will be shown
+        :type status: :obj:`bool`
+        """
+        if status:
+            self._markVLine.show()
+            self._markHLine.show()
+        else:
+            self._markVLine.hide()
+            self._markHLine.hide()
+
+    @QtCore.pyqtSlot(float, float)
+    def updatePositionMark(self, xdata, ydata, scaled=False):
+        """ updates the position mark
+
+        :param xdata: x pixel position
+        :type xdata: :obj:`float`
+        :param ydata: y-pixel position
+        :type ydata: :obj:`float`
+        :param scaled: scaled flag
+        :type scaled: :obj:`bool`
+        """
+        self._markcoordinates = [xdata, ydata]
+        pos0, pos1, scale0, scale1 = self._mainwidget.scale()
+        if pos0 is not None and not scaled:
+            if not self._mainwidget.transformations()[0]:
+                self._markVLine.setPos((xdata) * scale0 + pos0)
+                self._markHLine.setPos((ydata) * scale1 + pos1)
+            else:
+                self._markVLine.setPos((ydata) * scale1 + pos1)
+                self._markHLine.setPos((xdata) * scale0 + pos0)
+        else:
+            if not self._mainwidget.transformations()[0]:
+                self._markVLine.setPos(xdata)
+                self._markHLine.setPos(ydata)
+            else:
+                self._markVLine.setPos(ydata)
+                self._markHLine.setPos(xdata)
+
+    def transpose(self):
+        """ transposes Mark Position lines
+        """
+        v = self._markHLine.getPos()[1]
+        h = self._markVLine.getPos()[0]
+        self._markVLine.setPos(v)
+        self._markHLine.setPos(h)
+
+
+class MarkExtension(BaseMarkExtension):
+
+    def __init__(self, parent=None):
+        """ constructor
+
+        :param parent: parent object
+        :type parent: :class:`pyqtgraph.QtCore.QObject`
+        """
+        BaseMarkExtension.__init__(self, parent)
+
+        #: (:obj:`str`) tool name
+        self.name = "mark"
+
+        self._markVLine.setPen((0, 0, 255))
+        self._markHLine.setPen((0, 0, 255))
 
     def show(self, parameters):
         """ set subwidget properties
@@ -1796,22 +1865,9 @@ class MarkExtension(DisplayExtension):
         :type parameters: :class:`lavuelib.toolWidget.ToolParameters`
         """
         if parameters.marklines is not None:
-            self.__showMarkLines(parameters.marklines)
+            self._showMarkLines(parameters.marklines)
             self._enabled = parameters.marklines
 
-    def __showMarkLines(self, status):
-        """ shows or hides HV mark mouse lines
-
-        :param status: will be shown
-        :type status: :obj:`bool`
-        """
-        if status:
-            self.__markVLine.show()
-            self.__markHLine.show()
-        else:
-            self.__markVLine.hide()
-            self.__markHLine.hide()
-
     def mouse_position(self, x, y):
         """  sets vLine and hLine positions
 
@@ -1820,25 +1876,25 @@ class MarkExtension(DisplayExtension):
         :param y: y coordinate
         :type y: float
         """
-        if not self.__markcoordinates:
+        if not self._markcoordinates:
             now = time.time()
-            if now - self.__lasttime > self._refreshtime:
-                self.__lasttime = now
+            if now - self._lasttime > self._refreshtime:
+                self._lasttime = now
                 pos0, pos1, scale0, scale1 = self._mainwidget.scale()
                 if pos0 is not None:
                     if not self._mainwidget.transformations()[0]:
-                        self.__markVLine.setPos((x) * scale0 + pos0)
-                        self.__markHLine.setPos((y) * scale1 + pos1)
+                        self._markVLine.setPos((x) * scale0 + pos0)
+                        self._markHLine.setPos((y) * scale1 + pos1)
                     else:
-                        self.__markVLine.setPos((y) * scale1 + pos1)
-                        self.__markHLine.setPos((x) * scale0 + pos0)
+                        self._markVLine.setPos((y) * scale1 + pos1)
+                        self._markHLine.setPos((x) * scale0 + pos0)
                 else:
                     if not self._mainwidget.transformations()[0]:
-                        self.__markVLine.setPos(x)
-                        self.__markHLine.setPos(y)
+                        self._markVLine.setPos(x)
+                        self._markHLine.setPos(y)
                     else:
-                        self.__markVLine.setPos(y)
-                        self.__markHLine.setPos(x)
+                        self._markVLine.setPos(y)
+                        self._markHLine.setPos(x)
 
     def mouse_doubleclick(self, x, y, locked):
         """  sets vLine and hLine positions
@@ -1853,41 +1909,32 @@ class MarkExtension(DisplayExtension):
         if not locked:
             self.updatePositionMark(x, y)
 
-    @QtCore.pyqtSlot(float, float)
-    def updatePositionMark(self, xdata, ydata, scaled=False):
-        """ updates the position mark
 
-        :param xdata: x pixel position
-        :type xdata: :obj:`float`
-        :param ydata: y-pixel position
-        :type ydata: :obj:`float`
-        :param scaled: scaled flag
-        :type scaled: :obj:`bool`
-        """
-        self.__markcoordinates = [xdata, ydata]
-        pos0, pos1, scale0, scale1 = self._mainwidget.scale()
-        if pos0 is not None and not scaled:
-            if not self._mainwidget.transformations()[0]:
-                self.__markVLine.setPos((xdata) * scale0 + pos0)
-                self.__markHLine.setPos((ydata) * scale1 + pos1)
-            else:
-                self.__markVLine.setPos((ydata) * scale1 + pos1)
-                self.__markHLine.setPos((xdata) * scale0 + pos0)
-        else:
-            if not self._mainwidget.transformations()[0]:
-                self.__markVLine.setPos(xdata)
-                self.__markHLine.setPos(ydata)
-            else:
-                self.__markVLine.setPos(ydata)
-                self.__markHLine.setPos(xdata)
+class TrackingExtension(BaseMarkExtension):
 
-    def transpose(self):
-        """ transposes Mark Position lines
+    def __init__(self, parent=None):
+        """ constructor
+
+        :param parent: parent object
+        :type parent: :class:`pyqtgraph.QtCore.QObject`
         """
-        v = self.__markHLine.getPos()[1]
-        h = self.__markVLine.getPos()[0]
-        self.__markVLine.setPos(v)
-        self.__markHLine.setPos(h)
+        BaseMarkExtension.__init__(self, parent)
+
+        #: (:obj:`str`) tool name
+        self.name = "tracking"
+
+        self._markVLine.setPen((0, 255, 255))
+        self._markHLine.setPen((0, 255, 255))
+
+    def show(self, parameters):
+        """ set subwidget properties
+
+        :param parameters: tool parameters
+        :type parameters: :class:`lavuelib.toolWidget.ToolParameters`
+        """
+        if parameters.trackinglines is not None:
+            self._showMarkLines(parameters.trackinglines)
+            self._enabled = parameters.trackinglines
 
 
 class MaximaExtension(DisplayExtension):
