@@ -123,6 +123,18 @@ except AttributeError:
     #: (:obj:`bool`) PyTine imported
     PYTINE = False
 
+try:
+    import fabio
+    #: (:obj:`bool`) fabio can be imported
+    fbmj, fbmn, fbpa = fabio.version.split(".")
+    fmj = int(fbmj)
+    fmn = int(fbmn)
+    if fmj > 0 or fmn > 10:
+        FABIO11 = True
+    else:
+        FABIO11 = False
+except ImportError:
+    FABIO11 = False
 
 import socket
 import numpy as np
@@ -146,6 +158,8 @@ else:
     bytes = str
 
 
+globalmutex = QtCore.QMutex()
+
 logger = logging.getLogger("lavue")
 
 #: (:obj:`bool`) PyTango bug #213 flag related to EncodedAttributes in python3
@@ -191,7 +205,11 @@ def currenttime():
     # does not work on py2 and old py3
     # return datetime.datetime.utcnow().astimezone().isoformat()
     tzone = time.tzname[0]
-    tz = pytz.timezone(tzone)
+    try:
+        tz = pytz.timezone(tzone)
+    except Exception:
+        import tzlocal
+        tz = tzlocal.get_localzone()
     fmt = '%Y-%m-%dT%H:%M:%S.%f%z'
     starttime = tz.localize(datetime.datetime.now())
     return str(starttime.strftime(fmt))
@@ -1419,21 +1437,37 @@ class HTTPSource(BaseSource):
             try:
                 response = self.__get()
                 if response.ok:
+                    mdata = ""
                     name = self._configuration
                     data = response.content
-                    if str(data[:10]) == "###CBF: VE":
+                    if str(data[:10]) in ["###CBF: VE", "b'###CBF: VE'"]:
                         # print("[cbf source module]::metadata", name)
-                        try:
-                            nimg = np.frombuffer(data[:], dtype=np.uint8)
-                        except Exception:
-                            nimg = np.fromstring(data[:], dtype=np.uint8)
-                        img = imageFileHandler.CBFLoader().load(nimg)
+                        img = None
+                        if FABIO11:
+                            try:
+                                fimg = fabio.open(BytesIO(bytes(data)))
+                                img = fimg.data
+                                mdata = imageFileHandler.CBFLoader().metadata(
+                                    fimg.header.get(
+                                        "_array_data.header_contents"))
+                            except Exception as e:
+                                # print(str(e))
+                                logger.warning(str(e))
+                                img = None
+                        if img is None:
+                            try:
+                                nimg = np.frombuffer(data[:], dtype=np.uint8)
+                            except Exception:
+                                nimg = np.fromstring(data[:], dtype=np.uint8)
+                            img = imageFileHandler.CBFLoader().load(nimg)
+                            mdata = imageFileHandler.CBFLoader().metadata(nimg)
+
                         if img is None:
                             return None, None, None
                         if hasattr(img, "size") and img.size == 0:
                             return None, None, None
                         return (np.transpose(img),
-                                "%s (%s)" % (name, currenttime()), "")
+                                "%s (%s)" % (name, currenttime()), mdata)
                     else:
                         # print("[tif source module]::metadata", name)
                         if PILLOW and not self.__tiffloader:
@@ -1831,7 +1865,7 @@ class ASAPOSource(BaseSource):
             try:
                 (self.__server, self.__datasource,
                  self.__stream, self.__beamtime, self.__sourcepath,
-                 self.__token) = str(configuration).split(",", 5)
+                 self.__token) = str(configuration).split(",", 6)
                 self.__lastname = ""
                 self.__lastid = ""
                 self.__subcounter = 0
@@ -2065,16 +2099,29 @@ class ASAPOSource(BaseSource):
                 logger.info(
                     "ASAPOSource.getData: "
                     "[cbf source module]::metadata %s" % metadata["name"])
-                if type(data).__name__ == "ndarray":
-                    npdata = np.array(data[:], dtype="uint8")
-                else:
+                img = None
+                if FABIO11:
                     try:
-                        npdata = np.frombuffer(data[:], dtype=np.uint8)
-                    except Exception:
-                        npdata = np.fromstring(data[:], dtype=np.uint8)
-                img = imageFileHandler.CBFLoader().load(npdata)
-
-                mdata = imageFileHandler.CBFLoader().metadata(npdata, submeta)
+                        fimg = fabio.open(BytesIO(bytes(data)))
+                        img = fimg.data
+                        mdata = imageFileHandler.CBFLoader().metadata(
+                            fimg.header.get(
+                                "_array_data.header_contents"), submeta)
+                    except Exception as e:
+                        # print(str(e))
+                        logger.warning(str(e))
+                        img = None
+                if img is None:
+                    if type(data).__name__ == "ndarray":
+                        npdata = np.array(data[:], dtype="uint8")
+                    else:
+                        try:
+                            npdata = np.frombuffer(data[:], dtype=np.uint8)
+                        except Exception:
+                            npdata = np.fromstring(data[:], dtype=np.uint8)
+                    img = imageFileHandler.CBFLoader().load(npdata)
+                    mdata = imageFileHandler.CBFLoader().metadata(
+                        npdata, submeta)
 
                 if hasattr(img, "size") and img.size == 0:
                     if jsubmeta:
@@ -2313,21 +2360,32 @@ class HiDRASource(BaseSource):
                     else:
                         return (np.transpose(image), imagename, mdata)
                 return None, None, None
-            elif str(data[:10]) == "###CBF: VE":
+            elif str(data[:10]) in ["###CBF: VE", "b'###CBF: VE'"]:
                 # print("[cbf source module]::metadata", metadata["filename"])
                 logger.info(
                     "HiDRASource.getData: "
                     "[cbf source module]::metadata %s" % metadata["filename"])
-                if type(data).__name__ == "ndarray":
-                    npdata = np.array(data[:], dtype="uint8")
-                else:
+                img = None
+                if FABIO11:
                     try:
-                        npdata = np.frombuffer(data[:], dtype=np.uint8)
-                    except Exception:
-                        npdata = np.fromstring(data[:], dtype=np.uint8)
-                img = imageFileHandler.CBFLoader().load(npdata)
-
-                mdata = imageFileHandler.CBFLoader().metadata(npdata)
+                        fimg = fabio.open(BytesIO(bytes(data)))
+                        img = fimg.data
+                        mdata = imageFileHandler.CBFLoader().metadata(
+                            fimg.header.get("_array_data.header_contents"))
+                    except Exception as e:
+                        # print(str(e))
+                        logger.warning(str(e))
+                        img = None
+                if img is None:
+                    if type(data).__name__ == "ndarray":
+                        npdata = np.array(data[:], dtype="uint8")
+                    else:
+                        try:
+                            npdata = np.frombuffer(data[:], dtype=np.uint8)
+                        except Exception:
+                            npdata = np.fromstring(data[:], dtype=np.uint8)
+                    img = imageFileHandler.CBFLoader().load(npdata)
+                    mdata = imageFileHandler.CBFLoader().metadata(npdata)
 
                 if hasattr(img, "size") and img.size == 0:
                     return None, None, None
@@ -2586,9 +2644,10 @@ class TinePropSource(BaseSource):
             return "No Tine Property defined", "__ERROR__", None
         try:
             interval = int(dataFetchThread.GLOBALREFRESHRATE*1000)
-            prop = PyTine.get(address=self.__address,
-                              property=self.__prop,
-                              timeout=interval)
+            with QtCore.QMutexLocker(globalmutex):
+                prop = PyTine.get(address=self.__address,
+                                  property=self.__prop,
+                                  timeout=interval)
             rawdata = prop["data"]
 
             if "imageMatrix" in rawdata:
